Reactor.Process.Middleware
(reactor_process v0.4.3)
A Reactor middleware which records the pid of the original starting process.
A Reactor middleware which records the pid of the original starting process.